@@ -20,6 +20,11 @@ import io
 import struct
 import ngs_plumbing.dna as dna
 
+#Compatibility with Python 3
+import sys
+if sys.version_info[0] > 2:
+    long = int
+
 
 def ascii_val(char):
     return struct.unpack('@b', char)[0]
