@@ -20,6 +20,11 @@ from struct import unpack
 from ngs_plumbing.dna import PackedDNABytes
 from ngs_plumbing._libdna import slice_frombit2bytes, bit2_frombytes, bit2_frombytearray
 
+# Compatibility with Python 3
+import sys
+if sys.version_info[0] > 2:
+    xrange = range
+
 def kmerbytearray_frombytes_iter(unpacked, K, step=1):
     v = bytearray(unpacked)
     for i in xrange(0, len(unpacked)-K+1, step):
